"""
Type annotations for sagemaker-edge service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_sagemaker_edge/type_defs/)

Usage::

    ```python
    from types_aiobotocore_sagemaker_edge.type_defs import ChecksumTypeDef

    data: ChecksumTypeDef = ...
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List, Sequence, Union

from .literals import DeploymentStatusType, FailureHandlingPolicyType, ModelStateType

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal
if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "ChecksumTypeDef",
    "DeploymentModelTypeDef",
    "TimestampTypeDef",
    "ResponseMetadataTypeDef",
    "GetDeploymentsRequestRequestTypeDef",
    "GetDeviceRegistrationRequestRequestTypeDef",
    "DefinitionTypeDef",
    "DeploymentResultTypeDef",
    "EdgeMetricTypeDef",
    "EmptyResponseMetadataTypeDef",
    "GetDeviceRegistrationResultTypeDef",
    "EdgeDeploymentTypeDef",
    "ModelTypeDef",
    "GetDeploymentsResultTypeDef",
    "SendHeartbeatRequestRequestTypeDef",
)

ChecksumTypeDef = TypedDict(
    "ChecksumTypeDef",
    {
        "Type": Literal["SHA1"],
        "Sum": str,
    },
    total=False,
)

DeploymentModelTypeDef = TypedDict(
    "DeploymentModelTypeDef",
    {
        "ModelHandle": str,
        "ModelName": str,
        "ModelVersion": str,
        "DesiredState": ModelStateType,
        "State": ModelStateType,
        "Status": DeploymentStatusType,
        "StatusReason": str,
        "RollbackFailureReason": str,
    },
    total=False,
)

TimestampTypeDef = Union[datetime, str]
ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

GetDeploymentsRequestRequestTypeDef = TypedDict(
    "GetDeploymentsRequestRequestTypeDef",
    {
        "DeviceName": str,
        "DeviceFleetName": str,
    },
)

GetDeviceRegistrationRequestRequestTypeDef = TypedDict(
    "GetDeviceRegistrationRequestRequestTypeDef",
    {
        "DeviceName": str,
        "DeviceFleetName": str,
    },
)

DefinitionTypeDef = TypedDict(
    "DefinitionTypeDef",
    {
        "ModelHandle": str,
        "S3Url": str,
        "Checksum": ChecksumTypeDef,
        "State": ModelStateType,
    },
    total=False,
)

DeploymentResultTypeDef = TypedDict(
    "DeploymentResultTypeDef",
    {
        "DeploymentName": str,
        "DeploymentStatus": str,
        "DeploymentStatusMessage": str,
        "DeploymentStartTime": TimestampTypeDef,
        "DeploymentEndTime": TimestampTypeDef,
        "DeploymentModels": Sequence[DeploymentModelTypeDef],
    },
    total=False,
)

EdgeMetricTypeDef = TypedDict(
    "EdgeMetricTypeDef",
    {
        "Dimension": str,
        "MetricName": str,
        "Value": float,
        "Timestamp": TimestampTypeDef,
    },
    total=False,
)

EmptyResponseMetadataTypeDef = TypedDict(
    "EmptyResponseMetadataTypeDef",
    {
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetDeviceRegistrationResultTypeDef = TypedDict(
    "GetDeviceRegistrationResultTypeDef",
    {
        "DeviceRegistration": str,
        "CacheTTL": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

EdgeDeploymentTypeDef = TypedDict(
    "EdgeDeploymentTypeDef",
    {
        "DeploymentName": str,
        "Type": Literal["Model"],
        "FailureHandlingPolicy": FailureHandlingPolicyType,
        "Definitions": List[DefinitionTypeDef],
    },
    total=False,
)

ModelTypeDef = TypedDict(
    "ModelTypeDef",
    {
        "ModelName": str,
        "ModelVersion": str,
        "LatestSampleTime": TimestampTypeDef,
        "LatestInference": TimestampTypeDef,
        "ModelMetrics": Sequence[EdgeMetricTypeDef],
    },
    total=False,
)

GetDeploymentsResultTypeDef = TypedDict(
    "GetDeploymentsResultTypeDef",
    {
        "Deployments": List[EdgeDeploymentTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

_RequiredSendHeartbeatRequestRequestTypeDef = TypedDict(
    "_RequiredSendHeartbeatRequestRequestTypeDef",
    {
        "AgentVersion": str,
        "DeviceName": str,
        "DeviceFleetName": str,
    },
)
_OptionalSendHeartbeatRequestRequestTypeDef = TypedDict(
    "_OptionalSendHeartbeatRequestRequestTypeDef",
    {
        "AgentMetrics": Sequence[EdgeMetricTypeDef],
        "Models": Sequence[ModelTypeDef],
        "DeploymentResult": DeploymentResultTypeDef,
    },
    total=False,
)


class SendHeartbeatRequestRequestTypeDef(
    _RequiredSendHeartbeatRequestRequestTypeDef, _OptionalSendHeartbeatRequestRequestTypeDef
):
    pass
